package com.cloudpos.bluetoothprinterdemo;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothSocket;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import java.io.IOException;
import java.io.OutputStream;
import java.util.Set;
import java.util.UUID;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {
    private TextView textView;
    private Button conBtn, printBtn, disBtn;
    private String TAG = "bluetoothprinterdemo";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        textView = findViewById(R.id.textView);
        conBtn = findViewById(R.id.button1);
        printBtn = findViewById(R.id.button2);
        disBtn = findViewById(R.id.button3);
        conBtn.setOnClickListener(this);
        printBtn.setOnClickListener(this);
        disBtn.setOnClickListener(this);
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.button1:
                getDevices();
                break;
            case R.id.button2:
                send("Welcome to use WizarPOS_Print device!\nHere is the demo content :12345678901234567890123456789012345678901234567890\n");
                break;
            case R.id.button3:
                disconnect();
                break;
        }
    }

    BluetoothDevice dev;
    BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();

    public void getDevices() {

        if (adapter != null) {
            Set<BluetoothDevice> devices = adapter.getBondedDevices();
            if (devices.size() > 0) {
                for (BluetoothDevice device : devices) {
                    String addr = device.getAddress();
                    Log.d(TAG, "device.getAddress() = " + addr);
                    if (addr.equalsIgnoreCase("99:87:65:43:21:00")) {
                        dev = adapter.getRemoteDevice(addr);
                        connect();
                    }
                }
            } else {
                Log.d(TAG, "No paired bluetooth device!");
            }
        } else {
            Log.d(TAG, "This device has no bluetooth device!");
        }
    }

    private static final UUID uuid = UUID.fromString("00001101-0000-1000-8000-00805F9B34FB");
    public static BluetoothSocket bluetoothSocket = null;
    private static boolean isConnected = false;
    private static OutputStream outputStream = null;

    public boolean connect() {
        if (!isConnected) {
            try {
                bluetoothSocket = dev.createRfcommSocketToServiceRecord(uuid);
                bluetoothSocket.connect();
                outputStream = bluetoothSocket.getOutputStream();
                isConnected = true;
                if (adapter.isDiscovering()) {
                    Toast.makeText(this, "close BluetoothAdapter!", Toast.LENGTH_LONG).show();
                    adapter.isDiscovering();
                }
                textView.setText(dev.getName());
            } catch (Exception e) {
                e.printStackTrace();
                Toast.makeText(this, "Bluetooth connect fail!", Toast.LENGTH_LONG).show();
                return false;
            }
        }
        Toast.makeText(this, dev.getName() + "Bluetooth connect success!", Toast.LENGTH_SHORT).show();
        return true;
    }


    public void send(String sendData) {
        if (isConnected) {
            try {
                byte[] data;
                data = sendData.getBytes("gbk");
                write(data, data.length);
                flush();
            } catch (IOException e) {
                Toast.makeText(this, "print fail!", Toast.LENGTH_SHORT).show();
            }
        } else {
            Toast.makeText(this, "device not connect...", Toast.LENGTH_SHORT).show();
        }
    }

    public void write(byte[] buff, int length) {
        try {
            outputStream.write(buff, 0, length);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void flush() {
        try {
            outputStream.flush();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void disconnect() {
        try {
            if (outputStream != null) {
                outputStream.close();
            }
            if (bluetoothSocket != null) {
                bluetoothSocket.close();
                bluetoothSocket = null;
            }
            textView.setText("Connection disconnected!");
            isConnected = false;
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
